Learn R Programming

ra4bayesmeta (version 1.0-8)

M_inf_sigc: Optimization function for the SIGC(M) prior: Adjust the prior to a target relative latent model complexity (RLMC)

Description

Computes the parameter value \(M=M_{inf}\) of the SIGC(\(M\)) prior, such that the relative latent model complexity (RLMC) with respect to the reference threshold is approximately rlmc. The reference threshold is chosen as the (1-alpha)-quantile of the SIGC(\(M_{inf}\)) prior.

Usage

M_inf_sigc(rlmc, df, alpha=0.5, truncation=5*10^6)

Value

Parameter value \(M=M_{inf}\) of the SIGC(\(M\)) prior. Real number > 1.

Arguments

rlmc

target RLMC value. Real number in \((0,1)\).

df

data frame with one column "sigma" containing the standard errors of the estimates for the individual studies.

alpha

determines the (1-alpha)-quantile of the SIGC(\(M\)) prior, which is used as reference threshold. Defaults to 0.5 (i.e. the median).

truncation

upper bound for the parameter value \(M\). Defaults to the empirically determined value 5*10^6.

Warning

Occasionally, the formula for \(M_{inf}\) given in the Supplementary Material of Ott et al. (2021, Section 2.3.2) yields values larger than 5*10^6. This can cause numerical problems in the bayesmeta function. Therefore, we truncate the parameter value at the empirically determined threshold 5*10^6 by default.

Details

See the Supplementary Material of Ott et al. (2021), Section 2.3.2, for the formulas and explanations. Note that the parameter value \(M_{inf}\) does depend on the data set considered.

References

Ott, M., Plummer, M., Roos, M. (2021). Supplementary Material: How vague is vague? How informative is informative? Reference analysis for Bayesian meta-analysis. Statistics in Medicine. tools:::Rd_expr_doi("10.1002/sim.9076")

See Also

m_inf_sgc

Examples

Run this code
# extreme RLMC target value close to 1 used in Ott et al. (2021)
# for the aurigular acupuncture (AA) data set
data(aa)
M_inf_sigc(df=aa, rlmc=0.9999)
# for the respiratory tract infections (RTI) data set
data(rti)
M_inf_sigc(df=rti, rlmc=0.9999)

# 75% quantile instead of the median as ref. threshold
M_inf_sigc(df=rti, rlmc=0.9999, alpha=0.25)

Run the code above in your browser using DataLab