M_j_sigc: Optimization function for the SIGC(m) prior: Approximate Jeffreys reference posterior
Description
Numerically determines the parameter value \(M=M_J\) of the SIGC(\(M\)) prior,
such that the Hellinger distance between the marginal posteriors for the heterogeneity
standard deviation \(\tau\) induced by the SIGC(\(M_J\)) prior and Jeffreys (improper) reference prior
is minimal.
Parameter value \(M=M_J\) of the SIGC(M) prior. Real number > 1.
Arguments
df
data frame with one column "y" containing the (transformed) effect estimates for the individual studies and
one column "sigma" containing the standard errors of these estimates.
upper
upper bound for parameter \(M\). Real number in \((1,\infty)\).
digits
specifies the desired precision of the parameter value \(M=M_J\), i.e. to how many digits this value
should be determined. Possible values are 1,2,3. Defaults to 2.
mu.mean
mean of the normal prior for the effect mu.
mu.sd
standard deviation of the normal prior for the effect mu.
Warning
This function takes several minutes to run if the desired precision
is digits=2 and even longer for higher precision.
For some data sets, the optimal parameter value \(M=M_J\) is very large
(e.g. of order 9*10^5).
If this function returns \(M_J\)=upper, then
the optimal parameter value may be larger than upper.
Details
See the Supplementary Material of Ott et al. (2021, Section 2.6) for details.
References
Ott, M., Plummer, M., Roos, M. (2021). Supplementary Material:
How vague is vague? How informative is informative? Reference analysis for
Bayesian meta-analysis. Statistics in Medicine.
tools:::Rd_expr_doi("10.1002/sim.9076")