Learn R Programming

ra4bayesmeta (version 1.0-8)

aa: Auricular acupuncture data

Description

Meta-analysis data set including 4 randomized, controlled trials comparing treatment completion among cocaine dependents treated with auricular acupuncture versus sham acupuncture.

Usage

data(aa)

Arguments

Format

A data frame with 4 observations on the following 7 variables:

study

character string, label of the study

%TODO: specify the direction of the OR

f.t

integer, number of persons who did not complete treatment among those treated with auricular acupuncture

n.t

integer, number of persons treated with auricular acupuncture

f.c

integer, number of persons who did not complete treatment among those treated with sham acupuncture

n.c

integer, number of persons treated with sham acupuncture (control group)

y

numeric, log odds ratio estimates for the individual trials

sigma

numeric, standard error of the log odds ratio estimate for the individual trials

Details

This data set was originally analyzed by Gates et al. (2006) and reanalyzed by Bodnar et al. (2017).

The log odds ratio estimates and standard errors were computed using the escalc function in the package metafor.

References

Gates S, Smith LA, Foxcroft D. Auricular acupuncture for cocaine dependence. Cochrane Database of Systematic Reviews 2006, Issue 1. Art. No.: CD005192. tools:::Rd_expr_doi("10.1002/14651858.CD005192.pub2")

Examples

Run this code
data(aa)
str(aa)
# forest plot
forest(x=aa$y, sei=aa$sigma, xlab="log odds ratio")

Run the code above in your browser using DataLab