Learn R Programming

ra4bayesmeta (version 1.0-8)

cal_h_dist: Calibration of the Hellinger distance

Description

By default (if output="shift"), this function returns the mean of a unit-variance normal distribution, such that the Hellinger distance between this distribution and the standard normal distribution equals the given value. Offers the option to return the area of overlap (if output="ao") between these two unit-variance normal distributions instead. Gives an intuitive interpretation of Hellinger distance values.

Usage

cal_h_dist(h, output="shift")

Value

A vector of means (if output="shift") or areas of overlap (if output="ao"), respectively.

Arguments

h

vector of Hellinger distances, consisting of real numbers in [0,1]

output

either "shift" or "ao". Specifies if the output should be given as the shift between two unit-varaince normal distributions or as the area of overlap (AO) between these unit-varaince normal distributions

Details

For a given Hellinger distance h, there is a mean \(\mu(h)\), such that $$H(N(\mu(h), 1), N(0, 1))=h,$$ where H denotes the Hellinger distance. See Roos et al. (2015), Sect. 2.2 for details.

If output="shift", the function returns the shift \(\mu(h)\) between the two unit-variance normal distributions. If output="ao", the function returns the area of overlap between the \(N(\mu(h), 1)\) and \(N(0, 1)\) distributions. This area of overlap is given by $$AO(\mu(h)) = \Phi(\mu(h)/2 ;\mu(h), 1) + 1 - \Phi(\mu(h)/2 ;0, 1),$$ where \(\Phi(. ;\mu, \sigma^2)\) denotes the cumulative distribution function of the normal distribution with mean \(\mu\) and variance \(\sigma^2\). See Ott et al. (2021, Section 3.5) for more information on this area of overlap calibration.

References

Roos, M., Martins, T., Held, L., Rue, H. (2015). Sensitivity analysis for Bayesian hierarchical models. Bayesian Analysis 10(2), 321--349. https://projecteuclid.org/euclid.ba/1422884977

Ott, M., Plummer, M., Roos, M. (2021). How vague is vague? How informative is informative? Reference analysis for Bayesian meta-analysis. Statistics in Medicine 40, 4505--4521. tools:::Rd_expr_doi("10.1002/sim.9076")

Examples

Run this code
# calibration in terms of shifts
cal_h_dist(h=c(0.1, 0.5, 0.9))
# calibration in terms of areas of overlap
cal_h_dist(h=c(0.1, 0.5, 0.9), output="ao")

Run the code above in your browser using DataLab