Learn R Programming

ra4bayesmeta (version 1.0-8)

dsigc: Density function of the square-root inverse generalized conventional (SIGC) benchmark prior

Description

Density function of the SIGC distribution described in the Supplementary Material of Ott et al. (2021).

Usage

dsigc(x, M, C)

Value

Value of the density function at locations x, where \(x >= 0\). Vector of non-negative real numbers.

Arguments

x

vector of quantiles.

M

real number in \((1,\infty)\).

C

non-negative real number.

Details

The density function with domain \([0, \infty)\) is given by $$ \pi(x) = 4(M-1)Cx^{-5}(1+Cx^{-4})^{-M} $$ for \(x >= 0\). This density is obtained if the density function for variance components given in equation (2.15) in Berger & Deely (1988) is assigned to the precision (i.e. the inverse of the variance) and then transformed to the standard deviation scale. See the Supplementary Material of Ott et al. (2021), Section 2.2, for more information.

For meta-analsis data sets, Ott et al. (2021) choose \(C=\sigma_{ref}^{-2}\), where \(\sigma_{ref}\) is the reference standard deviation (see function sigma_ref) of the data set, which is defined as the geometric mean of the standard deviations of the individual studies.

References

Berger, J. O., Deely, J. (1988). A Bayesian approach to ranking and selection of related means with alternatives to analysis-of-variance methodology. Journal of the American Statistical Association 83(402), 364--373.

Ott, M., Plummer, M., Roos, M. (2021). Supplementary Material: How vague is vague? How informative is informative? Reference analysis for Bayesian meta-analysis. Statistics in Medicine. tools:::Rd_expr_doi("10.1002/sim.9076")

See Also

dsgc

Examples

Run this code
dsigc(x=c(0.1,0.5,1), M=1.2, C=10)

Run the code above in your browser using DataLab