Learn R Programming

ra4bayesmeta (version 1.0-8)

m_inf_sgc: Optimization function for the SGC(m) prior: Adjust the prior to a target relative latent model complexity (RLMC)

Description

Computes the parameter value \(m=m_{inf}\) of the SGC(\(m\)) prior, such that the relative latent model complexity (RLMC) with respect to the reference threshold is approximately rlmc. The reference threshold is chosen as the (1-alpha)-quantile of the SGC(\(m_{inf}\)) prior.

Usage

m_inf_sgc(rlmc, alpha=0.5)

Value

Parameter value \(m=m_{inf}\) of the SGC(\(m\)) prior. Real number > 1.

Arguments

rlmc

target RLMC value. Real number in \((0,1)\).

alpha

determines the (1-alpha)-quantile of the SGC(\(m\)) prior, which is used as reference threshold. Defaults to 0.5 (i.e. the median).

Details

See the Supplementary Material of Ott et al. (2021), Section 2.3.1, for the formulas and explanations. Note that the parameter value \(m_{inf}\) does not depend on the data set considered.

References

Ott, M., Plummer, M., Roos, M. (2021). Supplementary Material: How vague is vague? How informative is informative? Reference analysis for Bayesian meta-analysis. Statistics in Medicine. tools:::Rd_expr_doi("10.1002/sim.9076")

See Also

M_inf_sigc

Examples

Run this code
# extreme RLMC target value close to 0 used in Ott et al. (2021)
m_inf_sgc(rlmc=0.0001)

# 25% quantile instead of the median as ref. threshold
m_inf_sgc(rlmc=0.0001, alpha=0.75)

Run the code above in your browser using DataLab