m_j_sgc: Optimization function for the SGC(m) prior: Approximate Jeffreys reference posterior
Description
Numerically determines the parameter value \(m=m_J\) of the SGC(\(m\)) prior,
such that the Hellinger distance between the marginal posteriors for the heterogeneity
standard deviation \(\tau\) induced by the SGC(\(m_J\)) and Jeffreys (improper) reference prior
is minimal.
Parameter value \(m=m_J\) of the SGC(\(m\)) prior. Real number > 1.
Arguments
df
data frame with one column "y" containing the (transformed) effect estimates for the individual studies and
one column "sigma" containing the standard errors of these estimates.
upper
upper bound for parameter \(m\). Real number in \((1,\infty)\).
digits
specifies the desired precision of the parameter value \(m=m_J\), i.e. to how many digits this value
should be determined. Possible values are 1,2,3. Defaults to 2.
mu.mean
mean of the normal prior for the effect mu.
mu.sd
standard deviation of the normal prior for the effect mu.
Warning
This function takes several minutes to run if the desired precision
is digits=2 and even longer for higher precision.
Details
See the Supplementary Material of Ott et al. (2021, Section 2.6) for details.
References
Ott, M., Plummer, M., Roos, M. (2021). Supplementary Material:
How vague is vague? How informative is informative? Reference analysis for
Bayesian meta-analysis. Statistics in Medicine.
tools:::Rd_expr_doi("10.1002/sim.9076")