post_mu_fe: Normal posterior for the overall mean parameter in the fixed effects model
Description
This function computes the mean and the standard deviation of the
normal posterior distribution for the overall mean parameter mu in the fixed effects model.
Usage
post_mu_fe(df, mu.mean = 0, mu.sd = 4)
Value
A list with two elements: the first element "mean" and the second element "sd", which refer to the mean and the standard deviation of the normal posterior of mu.
Arguments
df
data frame with one column "y" containing the (transformed) effect estimates for the individual studies and
one column "sigma" containing the standard errors of these estimates.
mu.mean
mean of the normal prior for the overall mean parameter mu. Defaults to 0.
mu.sd
standard deviation of the normal prior for the overall mean parameter mu. Defaults to 4.
Details
For the fixed effects model, the normal posterior for the overall mean parameter mu can be computed analytically (under the common assumption of a normal prior on mu)
since this is a conjugate Bayesian normal-normal model.
See for example Ott et al. (2021), Equation (2) for the formula
(mu.mean corresponds to \(\nu\) and mu.sd corresponds to \(\gamma\)).
The default values for mu.mean and mu.sd
are suitable for effects mu on the log odds (ratio) scale (Roever, 2020).
References
Ott, M., Plummer, M., Roos, M. (2021). How vague is vague?
How informative is informative? Reference analysis for
Bayesian meta-analysis. Statistics in Medicine40, 4505--4521.
tools:::Rd_expr_doi("10.1002/sim.9076")
Roever C. Bayesian random-effects meta-analysis using the bayesmeta R package (2020). Journal of Statistical Software93(6), 1--51.
# load the aurigular acupuncture (AA) data setdata(aa)
# normal prior for log odds ratios suggested by Roever (2020)post_mu_fe(df=aa, mu.mean=0, mu.sd=4)