Computes a table of Hellinger distance estimates between the actual heterogeneity prior(s) specified and four benchmark heterogeneity priors proposed in the Supplementary Material of Ott et al. (2021).
pri_RA_5bm(df, tau.prior=list(function(x) dhalfnormal(x, scale=1)),
m_J=NA, M_J=NA, upper.J=3, digits.J=2,
m_inf=NA, M_inf=NA, rlmc0=0.0001, rlmc1=0.9999,
mu.mean=0, mu.sd=4)A list with two elements:
The first element named "table" is a matrix containing the Hellinger distance estimates and the
second element called "par" is a named vector giving the parameter values
of the benchmark priors.
The vector "par" has the following five components:
m_inf, M_J, m_J, M_inf and C.
The matrix "table" contains the Hellinger distance estimates between actual and benchmark
heterogeneity priors
and has \(4\) columns and \(n\) rows,
where \(n\) is the number of actual heterogeneity priors specified,
i.e. the length of the list tau.prior.
The columns of the matrix give the following Hellinger distance estimates between two heterogeneity priors (from left to right):
H(SGC(m_inf), pri_act):benchmark prior SGC(m_inf) and actual prior
H(SIGC(M_J), pri_act):benchmark prior SIGC(M_J) and actual prior
H(SGC(m_J), pri_act):benchmark prior SGC(m_J) and actual prior
H(SIGC(M_inf), pri_act):benchmark prior SIGC(M_inf) and actual prior
Each row corresponds to one actual heterogeneity prior
specified in the list tau.prior, in the same order
as in that list. Thus, the row names are:
pri_act_1:first actual prior in tau.prior
pri_act_2:second actual prior in tau.prior
pri_act_n:nth (last) actual prior in tau.prior
data frame with one column "y" containing the (transformed) effect estimates for the individual studies and one column "sigma" containing the standard errors of these estimates.
list of prior specifications, which are either functions returning the probability densities of the actual priors of interest for the heterogeneity parameter tau or character strings specifying priors implemented in the bayesmeta function. See the documentation of the argument tau.prior of the bayesmeta function for details.
parameter value \(m=m_J\) of the SGC(\(m\)) prior,
which induces a marignal posterior for the heterogeneity standard deviation tau close to Jeffreys reference posterior (wrt the Hellinger distance).
If set to NA (the default), this parameter is computed
using the function m_j_sgc and some other parameters.
parameter value \(M=M_J\) of the SIGC(\(M\)) prior,
which induces a marignal posterior for the heterogeneity standard deviation tau close to Jeffreys reference posterior (wrt the Hellinger distance).
If set to NA (the default), this parameter is computed
using the function M_j_sigc and some other parameters.
upper bound for the parameters M_J and m_J. Real number in \((1,\infty)\). Is required only if M_J=NA or m_J=NA.
specifies the desired precision of the parameter values \(M_J\) and \(m_J\), i.e. to how many digits these two values
should be determined. Possible values are 1,2,3. Defaults to 2.
Is required only if M_J=NA or m_J=NA.
parameter value \(m=m_{inf}\) of the SGC(\(m\)) prior,
such that the median relative latent model complexity (RLMC) is close to 0.
If set to NA (the default), this parameter is computed
using the function m_inf_sgc, such that the median RLMC is
approximately equal to rlmc0.
parameter value \(M=M_{inf}\) of the SIGC(\(M\)) prior,
such that the median relative latent model complexity (RLMC) is close to 1.
If set to NA (the default), this parameter is computed
using the function M_inf_sigc, such that the median RLMC is
approximately equal to rlmc1.
RLMC target value for the SGC(\(m_{inf}\)) benchmark prior (typically close to 0).
Is required only if m_inf=NA.
RLMC target value for the SIGC(\(M_{inf}\)) benchmark prior (typically close to 1).
Is required only if M_inf=NA.
mean of the normal prior for the effect mu.
standard deviation of the normal prior for the effect mu.
This function may take several minutes to run if the parameter m_J and/or M_J
is not specified,
especially if the desired precision is digits.J=2 or even digits.J=3.
The methodology for a prior reference analysis and the four proper heterogeneity benchmark priors used are introduced in the Supplementary Material of Ott et al. (2021, Sections 2.5 and 2.6). There, these four benchmark priors are denoted by SGC(\(m_J\)), SIGC(\(M_J\)), SGC(\(m_{inf}\)) and SIGC(\(M_{inf}\)).
Ott, M., Plummer, M., Roos, M. (2021). Supplementary Material: How vague is vague? How informative is informative? Reference analysis for Bayesian meta-analysis. Statistics in Medicine. tools:::Rd_expr_doi("10.1002/sim.9076")
post_RA_3bm,
pri_RA_fits
# for aurigular acupuncture (AA) data set with one
# actual half-normal and the "DuMouchel" heterogeneity prior
data(aa)
# warning: it takes ca. 7 min. to run this function
pri_RA_5bm(df=aa, tau.prior=list(function(t)dhalfnormal(t, scale=1),
"DuMouchel"))
# computation is much faster if m_J and M_J are specified
pri_RA_5bm(df=aa, tau.prior=list(function(t)dhalfnormal(t, scale=1),
"DuMouchel"),
m_J = 1.35, M_J = 1.3)
Run the code above in your browser using DataLab