Functionality for performing a principled reference analysis in the Bayesian normal-normal hierarchical model (NNHM) used for Bayesian meta-analysis.
Focuses on the choice of the prior for the between-study (heterogeneity) standard deviation \(\tau\).
Implements the methodology proposed in Ott et al. (2021).
The posterior reference analysis applies the Hellinger distance
to quantify the informativeness
of an actual heterogeneity prior of interest by
comparing the corresponding marginal posteriors
(for different parameters in the NNHM)
with posterior benchmarks.
The prior reference analysis
quantifies the informativeness
of an actual heterogeneity prior given the data by
computing its Hellinger distance to prior benchmarks.
The main posterior benchmark used is Jeffreys reference posterior
induced by a minimally informative improper reference prior (denoted by J) for the heterogeneity.
Two alternative proposals for additional posterior benchmarks are implemented.
The first, simpler proposal is described in Ott et al. (2021) and uses a benchmark induced by
an anti-conservative half-normal heterogeneity prior (denoted by HN0).
This benchmark allows us to discriminate between anti-conservative and conservative heterogeneity priors with respect to the reference prior.
The second, more involved proposal is introduced in the Supplementary Material of Ott et al. (2021) and uses up to four additional benchmarks induced by proper priors.
These benchmarks allow us to discriminate between strongly anti-conservative, reference affine, and strongly conservative heterogeneity priors.
All four benchmark priors belong to two closely related parametric families, the
so-called "square-root generalized conventional" (SGC) and
"inverse square-root generalized conventional" (SIGC) distributions,
which are derived from prior distributions for variance components
described in Berger & Deely (1988).
Note that most of these prior benchmarks also depend on the data set considered.
Functions which implement this second proposal use 3 benchmarks for the posterior reference analysis (Jeffreys reference posterior and two additional benchmarks induced by a highly anti-conservative heterogeneity prior SGC(\(m_{inf}\)) and a highly conservative heterogeneity prior SIGC(\(M_{inf}\)), respectively) and 5 benchmarks for the prior reference analysis (Jeffreys reference prior and 4 proper priors) and have a corresponding suffix _3bm or _5bm.
The corresponding functions without such a suffix implement the first proposal based on 2 heterogeneity benchmark priors (the half-normal and Jeffreys reference prior).
The main functions post_RA and post_RA_3bm
perform the reference analysis at the posterior level based on a data frame as input.
The functions fit_models_RA and fit_models_RA_5bm compute the benchmark heterogeneity priors and
corresponding (marginal) posteriors for a given data frame.
The more flexible functions post_RA_fits
and pri_RA_fits
perform
the reference analysis at the posterior level
and prior level
based on the provided benchmark and actual model fits (of class bayesmeta),
so that alternative benchmarks heterogeneity priors can also be used.
Functions for plotting the densities of the heterogeneity priors and
marginal posteriors for different parameters are also provided.
The functions operate on data frames which are compatible with the bayesmeta R package on CRAN.