Density function of the SGC distribution described in the Supplementary Material of Ott et al. (2021).
dsgc(x, m, C)Value of the density function at locations x, where \(x >= 0\). Vector of non-negative real numbers.
vector of quantiles.
real number in \((1,\infty)\).
non-negative real number.
The density function with domain \([0, \infty)\) is given by $$ \pi(x) = 2(m-1)Cx(1+Cx^2)^{-m} $$ for \(x >= 0\). This is the transformation of the density function for variance components given in equation (2.15) in Berger & Deely (1988) to the standard deviation scale. See the Supplementary Material of Ott et al. (2021), Section 2.2, for more information.
For meta-analsis data sets, Ott et al. (2021) choose
\(C=\sigma_{ref}^{-2}\),
where \(\sigma_{ref}\) is the reference standard deviation (see function sigma_ref) of the
data set,
which is defined as the geometric mean of the standard deviations
of the individual studies.
Berger, J. O., Deely, J. (1988). A Bayesian approach to ranking and selection of related means with alternatives to analysis-of-variance methodology. Journal of the American Statistical Association 83(402), 364--373.
Ott, M., Plummer, M., Roos, M. (2021). Supplementary Material: How vague is vague? How informative is informative? Reference analysis for Bayesian meta-analysis. Statistics in Medicine. tools:::Rd_expr_doi("10.1002/sim.9076")
dsigc
dsgc(x=c(0.1,0.5,1), m=1.2, C=10)
Run the code above in your browser using DataLab