Computes the reference standard deviation of the
given meta-analysis data set.
The reference standard deviation is defined as the geometric mean
of the standard deviations of the individual studies
(Sorbye & Rue 2014, equation (7)).
Usage
sigma_ref(df)
Value
The reference standard deviation of the data set. Non-negative real number.
Arguments
df
data frame with one column "sigma" containing the standard errors of the estimates for the individual studies.
References
Sorbye, S., Rue, H. (2014). Scaling intrinsic Gaussian Markov random field priors in
spatial modelling. Spatial Statistics8, 39--51.
tools:::Rd_expr_doi("10.1016/j.spasta.2013.06.004")